Chiptunomatic

Struct Chiptunomatic 

pub struct Chiptunomatic { /* private fields */ }

Implementations

Source

impl Chiptunomatic

pub fn new() -> Self

Initialize with the default plugin

pub fn with_default_plugins(self) -> Self

pub fn with_sample_rate(self, sample_rate: u32) -> Self

pub fn register_plugin(&mut self, plugin: Rc<dyn Plugin>)

pub fn register_default_plugins(&mut self)

pub fn plugin(&self) -> Rc<dyn Plugin>

pub fn modes(&self) -> Vec<&'static str>

Return the possible modes

pub fn modes_string(&self) -> Vec<String>

pub fn mode(&self) -> &'static str

Get the selected mode

pub fn mode_string(&self) -> String

pub fn set_mode(&mut self, mode: &String) -> Result<(), ChiptunomaticError>

Set the selected mode

pub fn song_metadata_from_seed( &self, seed: &[u8], data_byte_len: u64, ) -> Result<SongMetadata, GenerateError>

Builds SongMetadata from a bytes seed and stream byte length.

pub fn load_song_metadata_from_seed( &mut self, seed: &[u8], data_byte_len: u64, ) -> Result<SongMetadata, GenerateError>

Builds SongMetadata from a bytes seed and stream byte length.

pub fn song_metadata_from_string<S: Into<String>>( &self, s: S, data_byte_len: u64, ) -> Result<SongMetadata, GenerateError>

pub fn load_song_metadata_from_string<S: Into<String>>( &mut self, s: S, data_byte_len: u64, ) -> Result<SongMetadata, GenerateError>

pub fn song_metadata_from_path<P: AsRef<Path>>( &self, path: P, ) -> Result<SongMetadata, SongMetadataFromPathError>

pub fn load_song_metadata_from_path<P: AsRef<Path>>( &mut self, path: P, ) -> Result<SongMetadata, SongMetadataFromPathError>

pub fn song_note_reader(&self) -> SongNoteReader

Return a reader for the notes of a byte stream

pub fn read_song_notes<R: Read>( &self, reader: R, ) -> ReadSongNotes<R, SongNoteReader>

Iterate over the notes of a byte stream

pub fn drum_sample_generator<R: Rng + SeedableRng + 'static>( &self, ) -> DrumSampleGenerator

Return a generator for the drum samples

pub fn sample_drum_steps<R: Rng + SeedableRng + 'static>( &self, ) -> SampleDrumSteps

Iterate over the samples of the drum steps

pub fn file_to_wav<IP: AsRef<Path>, OP: AsRef<Path>>( &mut self, input_path: IP, output_path: OP, sample_rate: u32, mix_generator: MixGenerator, ) -> Result<(), ConvertWavError>

Convert a file to WAV. mode selects chiptune or lofi synthesis.